# ----------------------------------------------------------------------
# NSIS v2.0b3 install script for txt2tags
#
# This script is used by the NSIS program to build a Windows
# executable installer for the txt2tags program.
#
# NSIS     : http://nsis.sf.net
# txt2tags : http://txt2tags.sf.net
# Author   : Guaracy Monteiro
# License  : GPL
# Changelog:
#    2003-05-14  first release
# ----------------------------------------------------------------------

!define MUI_PRODUCT  "txt2tags"
!define MUI_VERSION  "1.5.1"
!define PROG_FILE    "txt2tags.pyw"
!define RELEASE_NAME "${MUI_PRODUCT}-${MUI_VERSION}"

!include "${NSISDIR}\Contrib\Modern UI\System.nsh"

;--------------------------------
;Configuration

  !define MUI_WELCOMEPAGE
  !define MUI_LICENSEPAGE
  !define MUI_DIRECTORYPAGE
  !define MUI_FINISHPAGE

  !define MUI_ABORTWARNING

  !define MUI_UNINSTALLER
  !define MUI_UNCONFIRMPAGE

; No images for now
;  !define MUI_HEADERBITMAP "${NSISDIR}\Contrib\Icons\modern-header 2.bmp"
;  !define MUI_SPECIALBITMAP "modern-wizard txt2tags.bmp"

  ;Language
  !insertmacro MUI_LANGUAGE "English"

  ;General
  OutFile "${RELEASE_NAME}.exe"

  ShowInstDetails show

  ;License page
  LicenseData "${RELEASE_NAME}\COPYING"

  ;Folder-selection page
  InstallDir "$PROGRAMFILES\${MUI_PRODUCT}"

;--------------------------------
;Installer Sections

Section "txt2tags" SecCopyUI

  ;;; IMPORTANT
  ; All the text files must be passed to 'unix2dos'
  ; before the installer packaging

  SetOutPath  "$INSTDIR\contrib\"
  File "${RELEASE_NAME}\contrib\*.*"
  SetOutPath  "$INSTDIR\extras\"
  File "${RELEASE_NAME}\extras\*.*"
  SetOutPath  "$INSTDIR\samples\"
  File "${RELEASE_NAME}\samples\*.*"
  SetOutPath  "$INSTDIR\userguide\"
  File "${RELEASE_NAME}\userguide\*.*"
  SetOutPath  "$INSTDIR"
  File "${RELEASE_NAME}\Changelog.html"
  File "${RELEASE_NAME}\COPYING"
  File "${RELEASE_NAME}\README.html"
  File "${RELEASE_NAME}\RULES"
  File "${RELEASE_NAME}\TODO"
  File "${RELEASE_NAME}\txt2tags"

  ; Add the .txt extension (Notepad association)
  Rename "$INSTDIR\COPYING"  "$INSTDIR\COPYING.txt"
  Rename "$INSTDIR\RULES"    "$INSTDIR\RULES.txt"
  Rename "$INSTDIR\TODO"     "$INSTDIR\TODO.txt"

  ; Add the Python extension to the executable
  Rename "$INSTDIR\txt2tags" "$INSTDIR\${PROG_FILE}"

  ; Create uninstaller
  WriteUninstaller "$INSTDIR\Uninstall.exe"
SectionEnd


;--------------------------------
; Post-installation

Section "-postinstall"

  ; "Start button" menu shortcuts
  SetOutPath "$SMPROGRAMS\${MUI_PRODUCT}"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\txt2tags.lnk" \
                 "$INSTDIR\${PROG_FILE}"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\Readme.lnk" \
                 "$INSTDIR\README.html"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\RULES.lnk" \
                 "$INSTDIR\RULES.txt"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\User Guide.lnk" \
                 "$INSTDIR\userguide\userguide.html"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\Txt2tags WebSite.lnk" \
                 "http://txt2tags.sf.net"
  CreateShortCut "$SMPROGRAMS\${MUI_PRODUCT}\Uninstall txt2tags.lnk" \
                 "$INSTDIR\Uninstall.exe"

  ; Make .t2t file extension association
  WriteRegStr HKCR ".t2t" "" "T2TFile"
  WriteRegStr HKCR "T2TFile" "" "Txt2tags File"

  WriteRegStr HKCR "T2TFile\shell" "" "open"
  WriteRegStr HKCR "T2TFile\shell\open\command" "" 'notepad.exe "%1"'

;TODO why it is not working?
;  WriteRegStr HKCR "T2TFile\shell\convert" "" "Convert in Txt2tags"
;  WriteRegStr HKCR "T2TFile\shell\convert\command" "" '"$INSTDIR\${PROG_FILE}" "%1"'

;TODO first we need an icon, then the QuickLaunch link
;  CreateShortCut "$QUICKLAUNCH\txt2tags.lnk" "$INSTDIR\txt2tags.py"

SectionEnd


;Display the Finish header
;Insert this macro after the sections if you are not using a finish page
!insertmacro MUI_SECTIONS_FINISHHEADER

;--------------------------------
;Descriptions

;!insertmacro MUI_FUNCTIONS_DESCRIPTION_BEGIN
;  !insertmacro MUI_DESCRIPTION_TEXT ${SecCopyUI} $(DESC_SecCopyUI)
;!insertmacro MUI_FUNCTIONS_DESCRIPTION_END

;--------------------------------
Function un.onUninstSuccess
  IfFileExists $INSTDIR 0 RemoveCont
    MessageBox MB_OK|MB_ICONEXCLAMATION "The uninstall wasn't complete;$\r$\nmanually delete any remnants in $INSTDIR."
  RemoveCont:
FunctionEnd

Function un.onInit
    MessageBox MB_YESNO "This will uninstall ${MUI_PRODUCT} ${MUI_VERSION} and ALL other files from$\r$\n$INSTDIR. Continue?" IDYES NoAbort
      Abort ; causes uninstaller to quit.
    NoAbort:
FunctionEnd

;--------------------------------
;Uninstaller Section

Section "Uninstall"
  RMDir /r "$INSTDIR\contrib"
  RMDir /r "$INSTDIR\extras"
  RMDir /r "$INSTDIR\samples"
  RMDir /r "$INSTDIR\userguide"

  Delete "$INSTDIR\Changelog.html"
  Delete "$INSTDIR\COPYING.txt"
  Delete "$INSTDIR\README.html"
  Delete "$INSTDIR\RULES.txt"
  Delete "$INSTDIR\TODO.txt"
  Delete "$INSTDIR\${PROG_FILE}"
  Delete "$INSTDIR\Uninstall.exe"
  RMDir  "$INSTDIR"

  RMDir /r "$SMPROGRAMS\${MUI_PRODUCT}"
;  Delete "$QUICKLAUNCH\txt2tags.lnk"

  DeleteRegKey HKCR ".t2t"
  DeleteRegKey HKCR "T2TFile"

  ; Display the Finish header
  !insertmacro MUI_UNFINISHHEADER
SectionEnd

;;;;;; FIM DO SCRIPT ;;;;;;
